scipy.sparse.compressed
=======================

.. automodule:: scipy.sparse.compressed

   
   
   .. rubric:: Functions

   .. autosummary::
   
      getdtype
      isdense
      isintlike
      isscalarlike
      isshape
      isspmatrix
      to_native
      upcast
      warn
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      spmatrix
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      SparseEfficiencyWarning
   
   